Changelog
---------

0.3.0 (2017-05-24)
~~~~~~~~~~~~~~~~~~~~~

- Adds the ability to define a success and an error url.
  [href]

0.2.0 (2017-05-24)
~~~~~~~~~~~~~~~~~~~~~

- Adds the ability to define the HTTP method with which the redirect target
  should be called.
  [href]

- Adds support for GET in addition to POST for the redirect view handler.
  [href]

0.1.0 (2017-05-23)
~~~~~~~~~~~~~~~~~~~~~

- Initial Release.
  [href]
